@@ -2,7 +2,7 @@ from __future__ import annotations
 
 from abc import ABC, abstractmethod
 from typing import Generic, TypeVar, Iterable, cast
-from typing_extensions import ClassVar, override
+from typing_extensions import override
 
 T = TypeVar("T")
 
@@ -13,11 +13,6 @@ class LazyProxy(Generic[T], ABC):
     This includes forwarding attribute access and othe methods.
     """
 
-    should_cache: ClassVar[bool] = False
-
-    def __init__(self) -> None:
-        self.__proxied: T | None = None
-
     # Note: we have to special case proxies that themselves return proxies
     # to support using a proxy as a catch-all for any random access, e.g. `proxy.foo.bar.baz`
 
@@ -50,25 +45,14 @@ class LazyProxy(Generic[T], ABC):
 
     @property  # type: ignore
     @override
-    def __class__(self) -> type:
+    def __class__(self) -> type:  # pyright: ignore
         proxied = self.__get_proxied__()
         if issubclass(type(proxied), LazyProxy):
             return type(proxied)
         return proxied.__class__
 
     def __get_proxied__(self) -> T:
-        if not self.should_cache:
-            return self.__load__()
-
-        proxied = self.__proxied
-        if proxied is not None:
-            return proxied
-
-        self.__proxied = proxied = self.__load__()
-        return proxied
-
-    def __set_proxied__(self, value: T) -> None:
-        self.__proxied = value
+        return self.__load__()
 
     def __as_proxied__(self) -> T:
         """Helper method that returns the current proxy, typed as the loaded object"""
